@@ -1,4 +1,4 @@
-# $Id: NodeList.pm,v 1.2 2002/03/09 14:19:52 phish Exp $
+# $Id: NodeList.pm 422 2002-11-08 17:10:30Z phish $
 
 package XML::LibXML::NodeList;
 use strict;
@@ -53,7 +53,9 @@ sub size {
 	scalar @$self;
 }
 
-sub get_node { # uses array index starting at 1, not 0
+sub get_node {
+    # uses array index starting at 1, not 0
+    # this is mainly because of XPath.
 	my $self = CORE::shift;
 	my ($pos) = @_;
 	$self->[$pos - 1];
@@ -92,6 +94,11 @@ sub to_number {
 			);
 }
 
+sub iterator {
+    warn "this function is obsolete!\nIt was disabled in version 1.54\n";
+    return undef;
+}
+
 1;
 __END__
 
@@ -167,4 +174,10 @@ Equivalent to perl's unshift function.
 Given a nodelist, prepends the list of nodes in $nodelist to the front of
 the current list.
 
+=head2 iterator()
+
+Will return a new nodelist iterator for the current nodelist. A
+nodelist iterator is usefull if more complex nodelist processing is
+needed.
+
 =cut
