@@ -1,4 +1,4 @@
-# $Id: Builder.pm,v 1.28 2003/02/04 23:01:33 phish Exp $
+# $Id: Builder.pm 492 2004-02-14 18:35:14Z pajas $
 
 package XML::LibXML::SAX::Builder;
 
@@ -39,6 +39,7 @@ sub start_document {
     $self->{NamespaceStack} = XML::NamespaceSupport->new;
     $self->{NamespaceStack}->push_context;
     $self->{Parent} = undef;
+    return ();
 }
 
 sub xml_decl {
@@ -51,6 +52,7 @@ sub xml_decl {
     if ( defined $decl->{Encoding} ) {
         $self->{DOM}->setEncoding( $decl->{Encoding} );
     }
+    return ();
 }
 
 sub end_document {
@@ -72,6 +74,7 @@ sub start_prefix_mapping {
     $self->{USENAMESPACESTACK} = 1;
 
     $self->{NamespaceStack}->declare_prefix( $ns->{Prefix}, $ns->{NamespaceURI} );
+    return ();
 }
 
 
@@ -79,6 +82,7 @@ sub end_prefix_mapping {
     my $self = shift;
     my $ns = shift;
     $self->{NamespaceStack}->undeclare_prefix( $ns->{Prefix} );
+    return ();
 }
 
 
@@ -169,6 +173,7 @@ sub start_element {
             $node->setAttribute($key => $attr);
         }
     }
+    return ();
 }
 
 sub end_element {
@@ -177,16 +182,19 @@ sub end_element {
 
     $self->{NamespaceStack}->pop_context;
     $self->{Parent} = $self->{Parent}->parentNode();
+    return ();
 }
 
 sub start_cdata {
     my $self = shift;
     $self->{IN_CDATA} = 1;
+    return ();
 }
 
 sub end_cdata {
     my $self = shift;
     $self->{IN_CDATA} = 0;
+    return ();
 }
 
 sub characters {
@@ -220,6 +228,7 @@ sub characters {
     }
 
     $self->{Parent}->addChild($node);
+    return ();
 }
 
 sub comment {
@@ -248,6 +257,7 @@ sub comment {
     else {
         $self->{DOM}->addChild($comment);
     }
+    return ();
 }
 
 sub processing_instruction {
@@ -262,6 +272,7 @@ sub processing_instruction {
     else {
         $self->{DOM}->addChild( $PI );
     }
+    return ();
 }
 
 sub warning {
@@ -292,20 +303,3 @@ sub fatal_error {
 1;
 
 __END__
-
-=head1 NAME
-
-XML::LibXML::SAX::Builder - build a LibXML tree from SAX events
-
-=head1 SYNOPSIS
-
-  my $builder = XML::LibXML::SAX::Builder->new();
-  my $gen = XML::Generator::DBI->new(Handler => $builder, dbh => $dbh);
-  my $dom = $gen->execute("SELECT * FROM Users");
-
-=head1 DESCRIPTION
-
-This is a SAX handler that generates a DOM tree from SAX events. Usage
-is as above. Input is accepted from any SAX1 or SAX2 event generator.
-
-=cut
