@@ -1,4 +1,4 @@
-# $Id: Parser.pm,v 1.16 2002/05/27 13:03:12 phish Exp $
+# $Id: Parser.pm 457 2003-07-12 22:17:55Z phish $
 
 package XML::LibXML::SAX::Parser;
 
@@ -6,10 +6,11 @@ use strict;
 use vars qw($VERSION @ISA);
 
 use XML::LibXML;
+use XML::LibXML::Common qw(:libxml);
 use XML::SAX::Base;
 use XML::SAX::DocumentLocator;
 
-$VERSION = '1.49';
+$VERSION = '1.50';
 @ISA = ('XML::SAX::Base');
 
 sub _parse_characterstream {
@@ -94,8 +95,12 @@ sub process_node {
         # ignore!
         # i may want to handle this one day, dunno yet
     }
+    elsif ($node_type == XML_DTD_NODE ) {
+        # ignore!
+        # i will support DTDs, but had no time yet.
+    }
     else {
-        warn("unsupported node type: $node_type");
+        # warn("unsupported node type: $node_type");
     }
 }
 
@@ -121,36 +126,59 @@ sub process_element {
         if ($attr->isa('XML::LibXML::Namespace')) {
             # TODO This needs fixing modulo agreeing on what
             # is the right thing to do here.
-            my ($localname, $p);
-            if (my $prefix = $attr->prefix) {
-                $key = "{" . $attr->href . "}" . $prefix;
-                $localname = $prefix;
-                $p = "xmlns";
+            unless ( defined $attr->name ) {
+                ## It's an atter like "xmlns='foo'"
+                $attribs->{"{}xmlns"} =
+                  {     
+                   Name         => "xmlns",
+                   LocalName    => "xmlns",
+                   Prefix       => "",     
+                   Value        => $attr->href,
+                   NamespaceURI => "",
+                  };
             }
             else {
-                $key = $attr->name;
-                $localname = $key;
-                $p = '';
+                my $prefix = "xmlns";
+                my $localname = $attr->localname;
+                my $key = "{http://www.w3.org/2000/xmlns/}";
+                my $name = "xmlns";
+
+                if ( defined $localname ) {
+                    $key .= $localname;
+                    $name.= ":".$localname;
+                }
+
+                $attribs->{$key} =
+                  {
+                   Name         => $name,
+                   Value        => $attr->href,
+                   NamespaceURI => "http://www.w3.org/2000/xmlns/",
+                   Prefix       => $prefix,
+                   LocalName    => $localname,
+                  };
             }
-            $attribs->{$key} =
-                {
-                    Name => $attr->prefix,
-                    Value => $attr->href,
-                    NamespaceURI => $attr->href,
-                    Prefix => $p,
-                    LocalName => $localname,
-                };
-            # push @ns_maps, $attribs->{$key};
         }
         else {
-            my $ns = $attr->namespaceURI || '';
+            my $ns = $attr->namespaceURI;
+
+            $ns = '' unless defined $ns;
             $key = "{$ns}".$attr->localname;
+            ## Not sure why, but $attr->name is coming through stripped
+            ## of its prefix, so we need to hand-assemble a real name.
+            my $name = $attr->name;
+            $name = "" unless defined $name;
+
+            my $prefix = $attr->prefix;
+            $prefix = "" unless defined $prefix;
+            $name = "$prefix:$name"
+              if index( $name, ":" ) < 0 && length $prefix;
+
             $attribs->{$key} =
                 {
-                    Name => $attr->name,
+                    Name => $name,
                     Value => $attr->value,
-                    NamespaceURI => $attr->namespaceURI,
-                    Prefix => $attr->prefix,
+                    NamespaceURI => $ns,
+                    Prefix => $prefix,
                     LocalName => $attr->localname,
                 };
         }
@@ -162,7 +190,7 @@ sub process_element {
         Name => $element->nodeName,
         Attributes => $attribs,
         NamespaceURI => $element->namespaceURI,
-        Prefix => $element->prefix,
+        Prefix => $element->prefix || "",
         LocalName => $element->localname,
     };
 
@@ -191,52 +219,3 @@ sub process_element {
 1;
 
 __END__
-
-=head1 NAME
-
-XML::LibXML::SAX::Parser - LibXML DOM based SAX Parser
-
-=head1 SYNOPSIS
-
-  my $handler = MySAXHandler->new();
-  my $parser = XML::LibXML::SAX::Parser->new(Handler => $handler);
-  $parser->parse_uri("foo.xml");
-
-=head1 DESCRIPTION
-
-This class allows you to generate SAX2 events using LibXML. Note
-that this is B<not> a stream based parser, instead it parses
-documents into a DOM and traverses the DOM tree. The reason being
-that libxml2's stream based parsing is extremely primitive,
-and would require an extreme amount of work to allow SAX2
-parsing in a stream manner.
-
-=head1 WARNING
-
-WARNING WARNING WARNING
-
-This is NOT a streaming SAX parser. As I said above, this parser
-reads the entire document into a DOM and serialises it. Some
-people couldn't read that in the paragraph above so I've added
-this warning.
-
-There are many reasons, but if you want to write a proper SAX
-parser using the libxml2 library, please feel free and send it
-along to me.
-
-=head1 API
-
-The API is exactly the same as any other Perl SAX2 parser. See
-L<XML::SAX::Intro> for details.
-
-Aside from the regular parsing methods, you can access the
-DOM tree traverser directly, using the generate() method:
-
-  my $parser = XML::LibXML::SAX::Parser->new(...);
-  $parser->generate($dom_tree);
-
-This is useful for serializing DOM trees, for example that
-you might have done prior processing on, or that you have
-as a result of XSLT processing.
-
-=cut
